@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply arpeggiation patterns to groups of notes
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Moo;
 use strictures 2;
@@ -82,7 +82,7 @@ Music::MelodicDevice::Arpeggiation - Apply arpeggiation patterns to groups of no
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ version 0.0101
 
   my $arp = Music::MelodicDevice::Arpeggiation->new;
 
-  my $arped = $arp->arp([60,64,67], 1, [0,1,2,1,0], 3);
+  my $arped = $arp->arp([60,64,67], 1, [0,1,2,1], 3);
 
 =head1 DESCRIPTION
 
